% Created by Marjolein Meddens 2012

clear all; close all;

% Folder where images are located
baseFolder = 'C:\...\PodosomeRecognition';

% Folder where output should be stored
saveFolder = 'C:\...\PodosomeRecognition\Output';

ActinImage = 'Actin';       % File name of actin image (should be located in 'baseFolder')

% Segmentation parameters

DispFig = 1;                % 1 if figures should be displayed
LowerDiameter = 0.4;        % Diameter of smallest features in um
UpperDiameter = 1.1;        % Diameter of largest features in um
FeatureSize = 0.8;          % Average diameter of features in um
PixelSize = 0.1;            % Pixelsize in um
RoundnessThreshold = 0.4;   % Roundness of an ellipse = Short Diameter / Long Diameter

% Ring analysis parameters

RingAnalysis = 1;           % 1 if ring analysis should be performed, 0 if not
RingImage = 'Vinculin';     % File name of image containing counterstain (should be located in 'baseFolder') (if actin is measured empty brackets can be placed ([]))

NumberErosion = 3;          % Pixel distance to which the core should be eroded
NumberDilation = 6;         % Pixel distance to which the core should be dilated

Ring = 1;                   % 1 if intensity of counter stain should be calculated, 0 if Actin intensity should be calculated
Cumulative = 0;             % 1 if all erosions and dilations should be taken together, 0 if intensity should be calculated for each pixel distance separately
PerPod = 0;                 % 1 if each podosome should be calculated separately (measurements for each podosome appear in a separate row), 0 if the analysis is done on the whole image simulateously

%% Code starts here

% Make the save folder if it doesn't exist
if ~exist(saveFolder,'dir')
    mkdir(saveFolder)
end

% Read Image
ImageIn = readim([baseFolder filesep ActinImage '.tif'],'');

% Segment podosomes
[FinalMask]=PodoFind(ImageIn,LowerDiameter,UpperDiameter,FeatureSize,PixelSize,RoundnessThreshold,DispFig);

% Save image containing segmentation mask
writeim(FinalMask*255,[saveFolder filesep 'Segmentation' ActinImage],'TIFF',1,[]);

if RingAnalysis
    % Set in which image grey values are measured
    if Ring
        MeasureImage = readim([baseFolder filesep RingImage '.tif'],'');
    else
        MeasureImage = ImageIn;
    end
    % Perform ring analysis
    [RingData,ColumnHeadings] = RingMeasure(MeasureImage,FinalMask,NumberErosion,NumberDilation,Cumulative,PerPod,PixelSize,UpperDiameter);
    % Save ring analysis output
    save([saveFolder filesep 'RingAnalysis.mat'],'RingData','ColumnHeadings');
end

